# Example Package

[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=guilhermedelemos_glemos-python&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=guilhermedelemos_glemos-python)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=guilhermedelemos_glemos-python&metric=coverage)](https://sonarcloud.io/summary/new_code?id=guilhermedelemos_glemos-python) 
[![Code Smells](https://sonarcloud.io/api/project_badges/measure?project=guilhermedelemos_glemos-python&metric=code_smells)](https://sonarcloud.io/summary/new_code?id=guilhermedelemos_glemos-python)
[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=guilhermedelemos_glemos-python&metric=sqale_rating)](https://sonarcloud.io/summary/new_code?id=guilhermedelemos_glemos-python)
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=guilhermedelemos_glemos-python&metric=security_rating)](https://sonarcloud.io/summary/new_code?id=guilhermedelemos_glemos-python)
[![Bugs](https://sonarcloud.io/api/project_badges/measure?project=guilhermedelemos_glemos-python&metric=bugs)](https://sonarcloud.io/summary/new_code?id=guilhermedelemos_glemos-python)
[![Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=guilhermedelemos_glemos-python&metric=vulnerabilities)](https://sonarcloud.io/summary/new_code?id=guilhermedelemos_glemos-python)
[![Duplicated Lines (%)](https://sonarcloud.io/api/project_badges/measure?project=guilhermedelemos_glemos-python&metric=duplicated_lines_density)](https://sonarcloud.io/summary/new_code?id=guilhermedelemos_glemos-python)
[![Reliability Rating](https://sonarcloud.io/api/project_badges/measure?project=guilhermedelemos_glemos-python&metric=reliability_rating)](https://sonarcloud.io/summary/new_code?id=guilhermedelemos_glemos-python)
[![Technical Debt](https://sonarcloud.io/api/project_badges/measure?project=guilhermedelemos_glemos-python&metric=sqale_index)](https://sonarcloud.io/summary/new_code?id=guilhermedelemos_glemos-python)

This is a simple example package.
